/* Including needed modules to compile this module/procedure */
#include "Cpu.h"
#include "Events.h"
#include "I2C.h"
#include "Bit1.h"
#include "Bit2.h"
#include "Bit3.h"
#include "Bit4.h"
/* Including shared modules, which are used for whole project */
#include "PE_Types.h" 
#include "PE_Error.h"
#include "PE_Const.h"
#include "IO_Map.h"

/* User includes (#include below this line is not maintained by Processor Expert) */
#include "Common.h"

int Buffer_temp[51];
int i;
LDD_TDeviceData *I2C_DeviceData = NULL;
LDD_TError Error;
TDataState DataState;
bool AS3935_interrupt_line = 0;
int RegisterValue;

static bool Read_Sensor_Regs(LDD_TDeviceData *I2CPtr, TDataState *DataState, uint8_t Address, uint8_t RegCount, uint8_t *Buffer)
{
  LDD_I2C_TBusState BusState;
  DataState->Sent = FALSE;
  I2C_MasterSendBlock(I2CPtr, &Address, sizeof(Address), LDD_I2C_NO_SEND_STOP);
  while (!DataState->Sent) {}
  if (!DataState->Sent) {
    return FALSE;
  }
  DataState->Received = FALSE;
  I2C_MasterReceiveBlock(I2CPtr, Buffer, RegCount, LDD_I2C_SEND_STOP);
  while (!DataState->Received) {}
  do {I2C_CheckBus(I2CPtr, &BusState);}
  while (BusState != LDD_I2C_IDLE);
  if (!DataState->Received) {
    return FALSE;
  }
  return TRUE;
}

static bool Write_Sensor_Regs(LDD_TDeviceData *I2CPtr, TDataState *DataState, uint8_t Address, uint8_t Data)
{
	LDD_I2C_TBusState BusState;
	uint8_t SendBuffer[2];
	  
	SendBuffer[0] = Address;
	SendBuffer[1] = Data;
		
	DataState->Sent = FALSE;
	I2C_MasterSendBlock(I2CPtr, &SendBuffer, 2U, LDD_I2C_SEND_STOP);
	while (!DataState->Sent) {}
	do {I2C_CheckBus(I2CPtr, &BusState);}
	while(BusState != LDD_I2C_IDLE); 
	if (!DataState->Sent) {
	  return FALSE;
	}
	return TRUE;
}

void my_delay(int y)
{
	int x;
	for (x=0; x < y; x++);
	{
		
	}
}

/*lint -save  -e970 Disable MISRA rule (6.3) checking. */
int main(void)
/*lint -restore Enable MISRA rule (6.3) checking. */
{
  /* Write your local variable definition here */
	 /* Write your local variable definition here */

  /*** Processor Expert internal initialization. DON'T REMOVE THIS CODE!!! ***/
  PE_low_level_init();
  /*** End of Processor Expert internal initialization.                    ***/

  I2C_DeviceData = I2C_Init(&DataState); 
  
  Bit2_PutVal(NULL,1);
  Bit3_PutVal(NULL,1);
  Bit4_PutVal(NULL,1);

  Write_Sensor_Regs(I2C_DeviceData, &DataState,0x3C, 0x96);	//set registers to default values 
  my_delay(100000);
  Write_Sensor_Regs(I2C_DeviceData, &DataState,0x08, 0x05);	//set capacitors
  my_delay(300000);
  Write_Sensor_Regs(I2C_DeviceData, &DataState,0x3D, 0x96);	//RC oscillators autocalibration
  my_delay(100000);
  
  for(;;)
  {
	  AS3935_interrupt_line = Bit1_GetVal(NULL);
	  if(AS3935_interrupt_line == 1)
	  {
		  my_delay(100000);
		  Read_Sensor_Regs(I2C_DeviceData, &DataState, 0x03, 1U, &RegisterValue); 

		  if((RegisterValue & 0x0F) == 1)
		  {
		  	  //noise detected			  
			  Bit2_PutVal(NULL,0);
			  my_delay(10000);
			  Bit2_PutVal(NULL,1);
			  my_delay(10000);  
		  }

		  if((RegisterValue & 0x0F) == 4)
		  {
		  	  //disturber detected			
			  Bit3_PutVal(NULL,0);
			  my_delay(10000);
			  Bit3_PutVal(NULL,1);
			  my_delay(10000);
		  }

		  if((RegisterValue & 0x0F) == 8)
		  {
		  	  //lightning detected
			  Bit4_PutVal(NULL,0);
			  my_delay(10000);
			  Bit4_PutVal(NULL,1);
			  my_delay(10000);
		  }	  
	  }			           
  }
  /*** Don't write any code pass this line, or it will be deleted during code generation. ***/
  /*** RTOS startup code. Macro PEX_RTOS_START is defined by the RTOS component. DON'T MODIFY THIS CODE!!! ***/
  #ifdef PEX_RTOS_START
    PEX_RTOS_START();                  /* Startup of the selected RTOS. Macro is defined by the RTOS component. */
  #endif
  /*** End of RTOS startup code.  ***/
  /*** Processor Expert end of main routine. DON'T MODIFY THIS CODE!!! ***/
  for(;;){}
  /*** Processor Expert end of main routine. DON'T WRITE CODE BELOW!!! ***/
} /*** End of main routine. DO NOT MODIFY THIS TEXT!!! ***/

/* END ProcessorExpert */
/*!
** @}
*/
/*
** ###################################################################
**
**     This file was created by Processor Expert 10.2 [05.06]
**     for the Freescale Kinetis series of microcontrollers.
**
** ###################################################################
*/
